@@ -473,6 +473,10 @@ def Lognormal_probability_plot(failures=None, right_censored=None, fit_gamma=Fal
             right_censored = np.array(right_censored)
         else:
             raise ValueError('right_censored must be a list or an array')
+
+
+    xmin_log = 10 ** (int(np.floor(np.log10(min(failures)))) - 1)
+    xmax_log = 10 ** (int(np.ceil(np.log10(max(failures)))) + 1)
     if max(failures) < 1:
         xvals = np.linspace(10 ** -3, 2, 1000)
     else:
@@ -535,14 +539,14 @@ def Lognormal_probability_plot(failures=None, right_censored=None, fit_gamma=Fal
             right_censored = right_censored - gamma
     # plot the failure points and format the scale and axes
     x, y = plotting_positions(failures=failures, right_censored=right_censored, h1=h1, h2=h2)
+    pts_xmin_log = 10 ** (int(np.floor(np.log10(min(x)))) - 1)
+    pts_xmax_log = 10 ** (int(np.ceil(np.log10(max(x)))) + 1)
     plt.scatter(x, y, marker='.', linewidth=2, c=data_color)
     plt.gca().set_yscale('function', functions=(__normal_forward, __normal_inverse))
     plt.xscale('log')
     plt.grid(b=True, which='major', color='k', alpha=0.3, linestyle='-')
     plt.grid(b=True, which='minor', color='k', alpha=0.08, linestyle='-')
     plt.ylim([0.0001, 0.9999])
-    pts_xmin_log = 10 ** (int(np.floor(np.log10(min(x)))) - 1)
-    pts_xmax_log = 10 ** (int(np.ceil(np.log10(max(x)))) + 1)
     plt.xlim([pts_xmin_log, pts_xmax_log])
     plt.gca().yaxis.set_minor_locator(FixedLocator(np.linspace(0, 1, 51)))
     ytickvals = [0.0001, 0.001, 0.01, 0.03, 0.05, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 0.95, 0.97, 0.99, 0.999, 0.9999]
